@@ -313,7 +313,7 @@ class NautilusMenu:
 try:
     def remove_linux_menu(name):
         save_loc = os.path.join(os.path.expanduser('~'), '.local/share/nautilus-python/extensions', name + '*')
-        os.system('rm {}'.format(save_loc))
+        os.system('rm "{}"'.format(save_loc))
 
 except:
     pass
